==> quarkus-core-2.8.0.Final-sources.jar: io/quarkus/runtime/ConfigConfig.java <==
package io.quarkus.runtime;

import java.net.URI;
import java.util.List;
import java.util.Optional;

import io.quarkus.runtime.annotations.ConfigItem;
import io.quarkus.runtime.annotations.ConfigPhase;
import io.quarkus.runtime.annotations.ConfigRoot;

/**
 * We don't really use this, because these are configurations for the config itself, so it causes a chicken / egg
 * problem, but we have it so the configurations can be properly documented.
 *
 * Relocation of the Config configurations to the Quarkus namespace is done in
 * {@link io.quarkus.runtime.configuration.ConfigUtils#configBuilder}.
 */
@ConfigRoot(name = ConfigItem.PARENT, phase = ConfigPhase.RUN_TIME)
public class ConfigConfig {
    /**
     * Additional config locations to be loaded with the Config. The configuration support multiple locations
     * separated by a comma and each must represent a valid {@link java.net.URI}.
     */
    @ConfigItem(name = "config.locations")
    public Optional<List<URI>> locations;

    /**
     * Accepts a single configuration profile name. If a configuration property cannot be found in the current active
     * profile, the config performs the same lookup in the profile set by this configuration.
     */
    @ConfigItem(name = "config.profile.parent")
    public Optional<String> profileParent;

    /**
     * A property that allows accessing a generated UUID.
     * It generates that UUID at startup time. So it changes between two starts including in dev mode.
     *
     * Access this generated UUID using expressions: `${quarkus.uuid}`.
     */
    @ConfigItem(name = "uuid")
    public Optional<String> uuid;
}

==> quarkus-core-3.2.9.Final-sources.jar: io/quarkus/runtime/ConfigConfig.java <==
package io.quarkus.runtime;

import java.net.URI;
import java.util.List;
import java.util.Optional;

import io.quarkus.runtime.annotations.ConfigItem;
import io.quarkus.runtime.annotations.ConfigPhase;
import io.quarkus.runtime.annotations.ConfigRoot;

/**
 * We don't really use this, because these are configurations for the config itself, so it causes a chicken / egg
 * problem, but we have it so the configurations can be properly documented.
 * <br>
 * Relocation of the Config configurations to the Quarkus namespace is done in
 * {@link io.quarkus.runtime.configuration.ConfigUtils#configBuilder}.
 */
@ConfigRoot(name = ConfigItem.PARENT, phase = ConfigPhase.RUN_TIME)
public class ConfigConfig {
    /**
     * Profile that will be active when Quarkus launches.
     */
    @ConfigItem(name = "profile", defaultValue = "prod")
    public Optional<String> profile;

    /**
     * Accepts a single configuration profile name. If a configuration property cannot be found in the current active
     * profile, the config performs the same lookup in the profile set by this configuration.
     */
    @ConfigItem(name = "config.profile.parent")
    public Optional<String> profileParent;

    /**
     * Additional config locations to be loaded with the Config. The configuration support multiple locations
     * separated by a comma and each must represent a valid {@link java.net.URI}.
     */
    @ConfigItem(name = "config.locations")
    public Optional<List<URI>> locations;

    /**
     * A property that allows accessing a generated UUID.
     * It generates that UUID at startup time. So it changes between two starts including in dev mode.
     * <br>
     * Access this generated UUID using expressions: `${quarkus.uuid}`.
     */
    @ConfigItem(name = "uuid")
    public Optional<String> uuid;
}
